use std::path::Path;

use config::Config;
use rocket::fs::NamedFile;
use rocket::response::content::RawHtml;
use rocket::{get, launch, routes, State};

mod config;
mod site;

#[get("/icon/<file>")]
async fn icon_res(file: &str) -> Option<NamedFile> {
    let path = Path::new("static/icons/").join(file);
    NamedFile::open(path).await.ok()
}

#[get("/")]
pub fn main_page(c: &State<Config>) -> RawHtml<String> {
    RawHtml(site::gen_site(c))
}

#[launch]
async fn rocket() -> _ {
    let conf_path: String = std::env::args()
        .skip(1)
        .next()
        .unwrap_or("./config.yml".to_string());
    let conf = config::Config::load(&conf_path);

    rocket::build()
        .mount("/", routes![main_page, icon_res])
        .manage(conf)
}
